@@ -32,7 +32,7 @@ class FastAPI(Starlette):
         self,
         *,
         debug: bool = False,
-        routes: List[BaseRoute] = None,
+        routes: Optional[List[BaseRoute]] = None,
         title: str = "FastAPI",
         description: str = "",
         version: str = "0.1.0",
@@ -44,13 +44,16 @@ class FastAPI(Starlette):
         redoc_url: Optional[str] = "/redoc",
         swagger_ui_oauth2_redirect_url: Optional[str] = "/docs/oauth2-redirect",
         swagger_ui_init_oauth: Optional[dict] = None,
-        middleware: Sequence[Middleware] = None,
-        exception_handlers: Dict[Union[int, Type[Exception]], Callable] = None,
-        on_startup: Sequence[Callable] = None,
-        on_shutdown: Sequence[Callable] = None,
+        middleware: Optional[Sequence[Middleware]] = None,
+        exception_handlers: Optional[
+            Dict[Union[int, Type[Exception]], Callable]
+        ] = None,
+        on_startup: Optional[Sequence[Callable]] = None,
+        on_shutdown: Optional[Sequence[Callable]] = None,
         openapi_prefix: str = "",
         root_path: str = "",
-        **extra: Dict[str, Any],
+        root_path_in_servers: bool = True,
+        **extra: Any,
     ) -> None:
         self.default_response_class = default_response_class
         self._debug = debug
@@ -71,7 +74,7 @@ class FastAPI(Starlette):
         self.title = title
         self.description = description
         self.version = version
-        self.servers = servers
+        self.servers = servers or []
         self.openapi_url = openapi_url
         self.openapi_tags = openapi_tags
         # TODO: remove when discarding the openapi_prefix parameter
@@ -83,6 +86,7 @@ class FastAPI(Starlette):
                 "https://fastapi.tiangolo.com/advanced/sub-applications/"
             )
         self.root_path = root_path or openapi_prefix
+        self.root_path_in_servers = root_path_in_servers
         self.docs_url = docs_url
         self.redoc_url = redoc_url
         self.swagger_ui_oauth2_redirect_url = swagger_ui_oauth2_redirect_url
@@ -98,7 +102,7 @@ class FastAPI(Starlette):
         self.openapi_schema: Optional[Dict[str, Any]] = None
         self.setup()
 
-    def openapi(self, openapi_prefix: str = "") -> Dict:
+    def openapi(self) -> Dict:
         if not self.openapi_schema:
             self.openapi_schema = get_openapi(
                 title=self.title,
@@ -106,7 +110,6 @@ class FastAPI(Starlette):
                 openapi_version=self.openapi_version,
                 description=self.description,
                 routes=self.routes,
-                openapi_prefix=openapi_prefix,
                 tags=self.openapi_tags,
                 servers=self.servers,
             )
@@ -114,10 +117,16 @@ class FastAPI(Starlette):
 
     def setup(self) -> None:
         if self.openapi_url:
+            urls = (server_data.get("url") for server_data in self.servers)
+            server_urls = {url for url in urls if url}
 
             async def openapi(req: Request) -> JSONResponse:
                 root_path = req.scope.get("root_path", "").rstrip("/")
-                return JSONResponse(self.openapi(root_path))
+                if root_path not in server_urls:
+                    if root_path and self.root_path_in_servers:
+                        self.servers.insert(0, {"url": root_path})
+                        server_urls.add(root_path)
+                return JSONResponse(self.openapi())
 
             self.add_route(self.openapi_url, openapi, include_in_schema=False)
         if self.openapi_url and self.docs_url:
@@ -177,27 +186,27 @@ class FastAPI(Starlette):
         path: str,
         endpoint: Callable,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        methods: List[str] = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        methods: Optional[List[str]] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
     ) -> None:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -232,27 +241,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        methods: List[str] = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        methods: Optional[List[str]] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -289,11 +298,11 @@ class FastAPI(Starlette):
         return decorator
 
     def add_api_websocket_route(
-        self, path: str, endpoint: Callable, name: str = None
+        self, path: str, endpoint: Callable, name: Optional[str] = None
     ) -> None:
         self.router.add_api_websocket_route(path, endpoint, name=name)
 
-    def websocket(self, path: str, name: str = None) -> Callable:
+    def websocket(self, path: str, name: Optional[str] = None) -> Callable:
         def decorator(func: Callable) -> Callable:
             self.add_api_websocket_route(path, func, name=name)
             return func
@@ -305,9 +314,9 @@ class FastAPI(Starlette):
         router: routing.APIRouter,
         *,
         prefix: str = "",
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
         default_response_class: Optional[Type[Response]] = None,
     ) -> None:
         self.router.include_router(
@@ -324,27 +333,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -378,27 +387,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -432,27 +441,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -486,27 +495,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -540,27 +549,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -594,27 +603,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -648,27 +657,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
@@ -702,27 +711,27 @@ class FastAPI(Starlette):
         self,
         path: str,
         *,
-        response_model: Type[Any] = None,
+        response_model: Optional[Type[Any]] = None,
         status_code: int = 200,
-        tags: List[str] = None,
-        dependencies: Sequence[Depends] = None,
-        summary: str = None,
-        description: str = None,
+        tags: Optional[List[str]] = None,
+        dependencies: Optional[Sequence[Depends]] = None,
+        summary: Optional[str] = None,
+        description: Optional[str] = None,
         response_description: str = "Successful Response",
-        responses: Dict[Union[int, str], Dict[str, Any]] = None,
-        deprecated: bool = None,
-        operation_id: str = None,
-        response_model_include: Union[SetIntStr, DictIntStrAny] = None,
+        responses: Optional[Dict[Union[int, str], Dict[str, Any]]] = None,
+        deprecated: Optional[bool] = None,
+        operation_id: Optional[str] = None,
+        response_model_include: Optional[Union[SetIntStr, DictIntStrAny]] = None,
         response_model_exclude: Union[SetIntStr, DictIntStrAny] = set(),
         response_model_by_alias: bool = True,
-        response_model_skip_defaults: bool = None,
+        response_model_skip_defaults: Optional[bool] = None,
         response_model_exclude_unset: bool = False,
         response_model_exclude_defaults: bool = False,
         response_model_exclude_none: bool = False,
         include_in_schema: bool = True,
-        response_class: Type[Response] = None,
-        name: str = None,
-        callbacks: List[routing.APIRoute] = None,
+        response_class: Optional[Type[Response]] = None,
+        name: Optional[str] = None,
+        callbacks: Optional[List[routing.APIRoute]] = None,
     ) -> Callable:
         if response_model_skip_defaults is not None:
             warning_response_model_skip_defaults_deprecated()  # pragma: nocover
