@@ -1078,6 +1078,18 @@ openapi_schema = {
                 ],
             }
         },
+        "/enum-status-code": {
+            "get": {
+                "responses": {
+                    "201": {
+                        "description": "Successful Response",
+                        "content": {"application/json": {"schema": {}}},
+                    },
+                },
+                "summary": "Get Enum Status Code",
+                "operationId": "get_enum_status_code_enum_status_code_get",
+            }
+        },
     },
     "components": {
         "schemas": {
@@ -1149,3 +1161,9 @@ def test_redoc():
     assert response.status_code == 200, response.text
     assert response.headers["content-type"] == "text/html; charset=utf-8"
     assert "redoc@next" in response.text
+
+
+def test_enum_status_code_response():
+    response = client.get("/enum-status-code")
+    assert response.status_code == 201, response.text
+    assert response.json() == "foo bar"
